from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MarkerCls:
	"""Marker commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: MarkerDestination, default value after init: MarkerDestination.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("marker", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_markerDestination_get', 'repcap_markerDestination_set', repcap.MarkerDestination.Nr1)

	def repcap_markerDestination_set(self, markerDestination: repcap.MarkerDestination) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to MarkerDestination.Default
		Default value after init: MarkerDestination.Nr1"""
		self._cmd_group.set_repcap_enum_value(markerDestination)

	def repcap_markerDestination_get(self) -> repcap.MarkerDestination:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, state: bool, window=repcap.Window.Default, marker=repcap.Marker.Default, markerDestination=repcap.MarkerDestination.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<ms>:LINK:TO:MARKer<mt> \n
		Snippet: driver.applications.k9X11Ad.calculate.marker.linkTo.marker.set(state = False, window = repcap.Window.Default, marker = repcap.Marker.Default, markerDestination = repcap.MarkerDestination.Default) \n
		This command links the normal source marker <ms> to any active destination marker <md> (normal or delta marker) . If you
		change the horizontal position of marker <md>, marker <ms> changes its horizontal position to the same value. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param markerDestination: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		markerDestination_cmd_val = self._cmd_group.get_repcap_cmd_value(markerDestination, repcap.MarkerDestination)
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:LINK:TO:MARKer{markerDestination_cmd_val} {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default, markerDestination=repcap.MarkerDestination.Default) -> bool:
		"""SCPI: CALCulate<n>:MARKer<ms>:LINK:TO:MARKer<mt> \n
		Snippet: value: bool = driver.applications.k9X11Ad.calculate.marker.linkTo.marker.get(window = repcap.Window.Default, marker = repcap.Marker.Default, markerDestination = repcap.MarkerDestination.Default) \n
		This command links the normal source marker <ms> to any active destination marker <md> (normal or delta marker) . If you
		change the horizontal position of marker <md>, marker <ms> changes its horizontal position to the same value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param markerDestination: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		markerDestination_cmd_val = self._cmd_group.get_repcap_cmd_value(markerDestination, repcap.MarkerDestination)
		response = self._core.io.query_str_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:LINK:TO:MARKer{markerDestination_cmd_val}?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'MarkerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MarkerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MinimumCls:
	"""Minimum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("minimum", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:BURSt:EVM:DIRect:MINimum \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.burst.evm.direct.minimum.get() \n
		This command returns the average, maximum or minimum EVM in dB for the IEEE 802.11b standard. This result is the value
		after filtering. For details see 'Modulation accuracy, flatness and tolerance parameters'. \n
			:return: result: list"""
		response = self._core.io.query_str(f'FETCh:BURSt:EVM:DIRect:MINimum?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, event: enums.EventOnce, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:STATistics:SCALe:AUTO \n
		Snippet: driver.calculate.statistics.scale.auto.set(event = enums.EventOnce.ONCE, window = repcap.Window.Default) \n
		This command initiates an automatic scaling of the diagram (x- and y-axis) . To obtain maximum resolution, the level
		range is set as a function of the measured spacing between peak power and the minimum power for the APD measurement and
		of the spacing between peak power and mean power for the CCDF measurement. In addition, the probability scale for the
		number of test points is adapted. To get valid results, you have to perform a complete sweep with synchronization to the
		end of the auto range process. This is only possible in single sweep mode. \n
			:param event: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(event, enums.EventOnce)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:STATistics:SCALe:AUTO {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	def set(self, rate: float) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:SRATe \n
		Snippet: driver.system.communicate.rdevice.oscilloscope.symbolRate.set(rate = 1.0) \n
		Determines whether the 10 GHz mode (default) or 20 GHz mode of the connected oscilloscope is used. The 20 GHZ mode
		achieves a higher decimation gain, but reduces the record length by half. \n
			:param rate: 10 GHz | 20 GHz No other sample rate values are allowed. Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(rate)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:SRATe {param}')

	def get(self) -> float:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:SRATe \n
		Snippet: value: float = driver.system.communicate.rdevice.oscilloscope.symbolRate.get() \n
		Determines whether the 10 GHz mode (default) or 20 GHz mode of the connected oscilloscope is used. The 20 GHZ mode
		achieves a higher decimation gain, but reduces the record length by half. \n
			:return: rate: 10 GHz | 20 GHz No other sample rate values are allowed. Unit: HZ"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:SRATe?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MfRbwCls:
	"""MfRbw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mfRbw", core, parent)

	def set(self, max_final_rbw: float) -> None:
		"""SCPI: [SENSe]:DIRected:MFRBw \n
		Snippet: driver.applications.k50Spurious.sense.directed.mfRbw.set(max_final_rbw = 1.0) \n
		No command help available \n
			:param max_final_rbw: Range: 1 Hz to 10 MHz , Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(max_final_rbw)
		self._core.io.write(f'SENSe:DIRected:MFRBw {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DIRected:MFRBw \n
		Snippet: value: float = driver.applications.k50Spurious.sense.directed.mfRbw.get() \n
		No command help available \n
			:return: max_final_rbw: Range: 1 Hz to 10 MHz , Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:DIRected:MFRBw?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def set(self, amount: float, notch=repcap.Notch.Default) -> None:
		"""SCPI: [SENSe]:NPRatio:NOTCh<notch>:COUNt \n
		Snippet: driver.sense.npratio.notch.count.set(amount = 1.0, notch = repcap.Notch.Default) \n
		Defines the number of notches for which results are determined. Note that even if bandwidths for further notches are
		defined, only the number specified here are actually calculated and displayed. \n
			:param amount: integer Range: 1 to 25
			:param notch: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')
		"""
		param = Conversions.decimal_value_to_str(amount)
		notch_cmd_val = self._cmd_group.get_repcap_cmd_value(notch, repcap.Notch)
		self._core.io.write(f'SENSe:NPRatio:NOTCh{notch_cmd_val}:COUNt {param}')

	def get(self, notch=repcap.Notch.Default) -> float:
		"""SCPI: [SENSe]:NPRatio:NOTCh<notch>:COUNt \n
		Snippet: value: float = driver.sense.npratio.notch.count.get(notch = repcap.Notch.Default) \n
		Defines the number of notches for which results are determined. Note that even if bandwidths for further notches are
		defined, only the number specified here are actually calculated and displayed. \n
			:param notch: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')
			:return: amount: integer Range: 1 to 25"""
		notch_cmd_val = self._cmd_group.get_repcap_cmd_value(notch, repcap.Notch)
		response = self._core.io.query_str(f'SENSe:NPRatio:NOTCh{notch_cmd_val}:COUNt?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	@property
	def handover(self):
		"""handover commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_handover'):
			from .Handover import HandoverCls
			self._handover = HandoverCls(self._core, self._cmd_group)
		return self._handover

	@property
	def start(self):
		"""start commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_start'):
			from .Start import StartCls
			self._start = StartCls(self._core, self._cmd_group)
		return self._start

	@property
	def stop(self):
		"""stop commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stop'):
			from .Stop import StopCls
			self._stop = StopCls(self._core, self._cmd_group)
		return self._stop

	def clone(self) -> 'FrequencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrequencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AchannelCls:
	"""Achannel commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("achannel", core, parent)

	def set(self, value: bool) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer[:STATe]:ACHannel \n
		Snippet: driver.applications.k18AmplifierEt.sense.power.achannel.filterPy.state.achannel.set(value = False) \n
		This command turns the weighting filter for the adjacent channel on and off. \n
			:param value: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(value)
		self._core.io.write(f'SENSe:POWer:ACHannel:FILTer:STATe:ACHannel {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer[:STATe]:ACHannel \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.sense.power.achannel.filterPy.state.achannel.get() \n
		This command turns the weighting filter for the adjacent channel on and off. \n
			:return: value: No help available"""
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:FILTer:STATe:ACHannel?')
		return Conversions.str_to_bool(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AddCls:
	"""Add commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("add", core, parent)

	def set(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:ADD \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.add.set(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default) \n
		This command adds a bandwidth part to the signal configuration. The new bandwidth part has the highest index number.
		Index numbers start at 0. For example, if you already have three bandwidth parts and a add a fourth one, the new one has
		the index number 3. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
		"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:ADD')

	def set_with_opc(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, opc_timeout_ms: int = -1) -> None:
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:ADD \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.add.set_with_opc(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default) \n
		This command adds a bandwidth part to the signal configuration. The new bandwidth part has the highest index number.
		Index numbers start at 0. For example, if you already have three bandwidth parts and a add a fourth one, the new one has
		the index number 3. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:ADD', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TradeoffCls:
	"""Tradeoff commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tradeoff", core, parent)

	def set(self, power_linearity_tradeoff: float) -> None:
		"""SCPI: CONFigure:DDPD:TRADeoff \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.tradeoff.set(power_linearity_tradeoff = 1.0) \n
		This command defines the power / linearity tradeoff for direct DPD calculation.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on direct DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
			:param power_linearity_tradeoff: numeric value Unit: PCT
		"""
		param = Conversions.decimal_value_to_str(power_linearity_tradeoff)
		self._core.io.write(f'CONFigure:DDPD:TRADeoff {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:DDPD:TRADeoff \n
		Snippet: value: float = driver.applications.k18AmplifierEt.configure.ddpd.tradeoff.get() \n
		This command defines the power / linearity tradeoff for direct DPD calculation.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on direct DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
			:return: power_linearity_tradeoff: numeric value Unit: PCT"""
		response = self._core.io.query_str(f'CONFigure:DDPD:TRADeoff?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UplinkCls:
	"""Uplink commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uplink", core, parent)

	def set(self, test_model: str, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: MMEMory:LOAD[:CC<cc>]:TMOD:UL \n
		Snippet: driver.applications.k10Xlte.massMemory.load.cc.tmod.uplink.set(test_model = '1', carrierComponent = repcap.CarrierComponent.Default) \n
		This command loads an O-RAN test case. \n
			:param test_model: string String that contains the name of the O-RAN test case, e.g. 'TC 3.2.3.7.1'.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.value_to_quoted_str(test_model)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'MMEMory:LOAD:CC{carrierComponent_cmd_val}:TMOD:UL {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> str:
		"""SCPI: MMEMory:LOAD[:CC<cc>]:TMOD:UL \n
		Snippet: value: str = driver.applications.k10Xlte.massMemory.load.cc.tmod.uplink.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command loads an O-RAN test case. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: test_model: string String that contains the name of the O-RAN test case, e.g. 'TC 3.2.3.7.1'."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'MMEMory:LOAD:CC{carrierComponent_cmd_val}:TMOD:UL?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SthresholdCls:
	"""Sthreshold commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sthreshold", core, parent)

	def set(self, threshold: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:PSPectrum:STHReshold \n
		Snippet: driver.applications.k6Pulse.calculate.pspectrum.sthreshold.set(threshold = 1.0, window = repcap.Window.Default) \n
		Defines the minimum section size for Pulse-to-Pulse Spectrum displays. Sections that are smaller than the threshold are
		ignored and considered to be part of the detected gap. For more information see 'Parameter spectrum calculation'. \n
			:param threshold: Minimum section size as a percentage of the block size (see method RsFsw.Applications.K6_Pulse.Calculate.Pspectrum.BlockSize.set) Range: 0 to 100
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(threshold)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:PSPectrum:STHReshold {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:PSPectrum:STHReshold \n
		Snippet: value: float = driver.applications.k6Pulse.calculate.pspectrum.sthreshold.get(window = repcap.Window.Default) \n
		Defines the minimum section size for Pulse-to-Pulse Spectrum displays. Sections that are smaller than the threshold are
		ignored and considered to be part of the detected gap. For more information see 'Parameter spectrum calculation'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: threshold: Minimum section size as a percentage of the block size (see method RsFsw.Applications.K6_Pulse.Calculate.Pspectrum.BlockSize.set) Range: 0 to 100"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:PSPectrum:STHReshold?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VideoCls:
	"""Video commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("video", core, parent)

	def set(self, arg_0: float, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: TRIGger<tp>[:SEQuence]:LEVel:VIDeo \n
		Snippet: driver.applications.k70Vsa.trigger.sequence.level.video.set(arg_0 = 1.0, triggerPort = repcap.TriggerPort.Default) \n
		No command help available \n
			:param arg_0: No help available
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'TRIGger{triggerPort_cmd_val}:SEQuence:LEVel:VIDeo {param}')

	def get(self, triggerPort=repcap.TriggerPort.Default) -> float:
		"""SCPI: TRIGger<tp>[:SEQuence]:LEVel:VIDeo \n
		Snippet: value: float = driver.applications.k70Vsa.trigger.sequence.level.video.get(triggerPort = repcap.TriggerPort.Default) \n
		No command help available \n
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: arg_0: No help available"""
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'TRIGger{triggerPort_cmd_val}:SEQuence:LEVel:VIDeo?')
		return Conversions.str_to_float(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from ..........Internal.Types import DataType
from ..........Internal.ArgSingleList import ArgSingleList
from ..........Internal.ArgSingle import ArgSingle
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, sb_gaps: enums.SubBlockGaps, state: bool, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>:MANual:UPPer[:CACLr][:RELative]:STATe \n
		Snippet: driver.calculate.limit.acPower.gap.manual.upper.caclr.relative.state.set(sb_gaps = enums.SubBlockGaps.AB, state = False, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		This command turns the relative limit check for the specified upper gap (CACLR) channel on and off. You have to activate
		the general ACLR limit check before using this command with method RsFsw.Calculate.Limit.AcPower.State.set. This command
		is only available for for asymmetrical (manual) configuration of gap channels (see [SENSe:]POWer:ACHannel:GAP<gap>:MODE) . \n
			:param sb_gaps: AB | BC | CD | DE | EF | FG | GH Name of the gap, defined by the letters of the surrounding sub blocks (e.g. 'AB' for the gap between sub blocks A and B) .
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('sb_gaps', sb_gaps, DataType.Enum, enums.SubBlockGaps), ArgSingle('state', state, DataType.Boolean))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:MANual:UPPer:CACLr:RELative:STATe {param}'.rstrip())

	def get(self, sb_gaps: enums.SubBlockGaps, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> bool:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>:MANual:UPPer[:CACLr][:RELative]:STATe \n
		Snippet: value: bool = driver.calculate.limit.acPower.gap.manual.upper.caclr.relative.state.get(sb_gaps = enums.SubBlockGaps.AB, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		This command turns the relative limit check for the specified upper gap (CACLR) channel on and off. You have to activate
		the general ACLR limit check before using this command with method RsFsw.Calculate.Limit.AcPower.State.set. This command
		is only available for for asymmetrical (manual) configuration of gap channels (see [SENSe:]POWer:ACHannel:GAP<gap>:MODE) . \n
			:param sb_gaps: AB | BC | CD | DE | EF | FG | GH Name of the gap, defined by the letters of the surrounding sub blocks (e.g. 'AB' for the gap between sub blocks A and B) .
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		param = Conversions.enum_scalar_to_str(sb_gaps, enums.SubBlockGaps)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:MANual:UPPer:CACLr:RELative:STATe? {param}')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, ppdu_type: enums.PpduTypeB) -> None:
		"""SCPI: CONFigure:WLAN:STBC:AUTO:TYPE \n
		Snippet: driver.applications.k91Wlan.configure.wlan.stbc.auto.typePy.set(ppdu_type = enums.PpduTypeB.ALL) \n
		This remote control command specifies which PPDUs are analyzed according to STBC streams (for IEEE 802.11n, ac standards
		only) . \n
			:param ppdu_type: FBURst | ALL | M0 | M1 | M2 | D0 | D1 | D2 FBURst The STBC of the first PPDU is detected and subsequent PPDUs are analyzed only if they have the same STBC (corresponds to 'Auto, same type as first PPDU') ALL All recognized PPDUs are analyzed according to their individual STBC (corresponds to 'Auto, individually for each PPDU') M0 | M1 | M2 Measure only if STBC field = 0 | 1 | 2 For details see 'STBC Field' D0 | D1 | D2 Demod all as STBC field = 0 | 1 | 2 For details see 'STBC Field'
		"""
		param = Conversions.enum_scalar_to_str(ppdu_type, enums.PpduTypeB)
		self._core.io.write(f'CONFigure:WLAN:STBC:AUTO:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PpduTypeB:
		"""SCPI: CONFigure:WLAN:STBC:AUTO:TYPE \n
		Snippet: value: enums.PpduTypeB = driver.applications.k91Wlan.configure.wlan.stbc.auto.typePy.get() \n
		This remote control command specifies which PPDUs are analyzed according to STBC streams (for IEEE 802.11n, ac standards
		only) . \n
			:return: ppdu_type: FBURst | ALL | M0 | M1 | M2 | D0 | D1 | D2 FBURst The STBC of the first PPDU is detected and subsequent PPDUs are analyzed only if they have the same STBC (corresponds to 'Auto, same type as first PPDU') ALL All recognized PPDUs are analyzed according to their individual STBC (corresponds to 'Auto, individually for each PPDU') M0 | M1 | M2 Measure only if STBC field = 0 | 1 | 2 For details see 'STBC Field' D0 | D1 | D2 Demod all as STBC field = 0 | 1 | 2 For details see 'STBC Field'"""
		response = self._core.io.query_str(f'CONFigure:WLAN:STBC:AUTO:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.PpduTypeB)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 36 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def iqOffset(self):
		"""iqOffset commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqOffset'):
			from .IqOffset import IqOffsetCls
			self._iqOffset = IqOffsetCls(self._core, self._cmd_group)
		return self._iqOffset

	@property
	def packet(self):
		"""packet commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_packet'):
			from .Packet import PacketCls
			self._packet = PacketCls(self._core, self._cmd_group)
		return self._packet

	@property
	def psdu(self):
		"""psdu commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_psdu'):
			from .Psdu import PsduCls
			self._psdu = PsduCls(self._core, self._cmd_group)
		return self._psdu

	@property
	def shr(self):
		"""shr commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_shr'):
			from .Shr import ShrCls
			self._shr = ShrCls(self._core, self._cmd_group)
		return self._shr

	@property
	def sts(self):
		"""sts commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_sts'):
			from .Sts import StsCls
			self._sts = StsCls(self._core, self._cmd_group)
		return self._sts

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SequenceCls:
	"""Sequence commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sequence", core, parent)

	def set(self, state: enums.DpdOrder) -> None:
		"""SCPI: CONFigure:DPD:SEQuence \n
		Snippet: driver.applications.k18AmplifierEt.configure.dpd.sequence.set(state = enums.DpdOrder.AMFirst) \n
		This command selects the order in which the 'AM/AM' and 'AM/PM' distortion are applied. Available when both have been
		turned on.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on polynomial DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) .
			- Turn on both 'AM/AM' and 'AM/PM' calculation (method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.Amam.State.set / method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.AmPm.State.set) . \n
			:param state: AMFirst Calculates the 'AM/AM' distortion first, then the 'AM/PM' distortion. PMFirst Calculates the 'AM/PM' distortion first, then the 'AM/AM' distortion.
		"""
		param = Conversions.enum_scalar_to_str(state, enums.DpdOrder)
		self._core.io.write(f'CONFigure:DPD:SEQuence {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DpdOrder:
		"""SCPI: CONFigure:DPD:SEQuence \n
		Snippet: value: enums.DpdOrder = driver.applications.k18AmplifierEt.configure.dpd.sequence.get() \n
		This command selects the order in which the 'AM/AM' and 'AM/PM' distortion are applied. Available when both have been
		turned on.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on polynomial DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) .
			- Turn on both 'AM/AM' and 'AM/PM' calculation (method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.Amam.State.set / method RsFsw.Applications.K18_AmplifierEt.Configure.Dpd.AmPm.State.set) . \n
			:return: state: AMFirst Calculates the 'AM/AM' distortion first, then the 'AM/PM' distortion. PMFirst Calculates the 'AM/PM' distortion first, then the 'AM/AM' distortion."""
		response = self._core.io.query_str(f'CONFigure:DPD:SEQuence?')
		return Conversions.str_to_scalar_enum(response, enums.DpdOrder)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScenterCls:
	"""Scenter commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scenter", core, parent)

	def set(self, frequency: float, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:SCENter \n
		Snippet: driver.sense.espectrum.scenter.set(frequency = 1.0, subBlock = repcap.SubBlock.Default) \n
		This command defines the center frequency of the selected sub block in a Multi-SEM measurement. \n
			:param frequency: Frequency within the currently defined global span (see [SENSe:]FREQuency:SPAN and [SENSe:]FREQuency:CENTer) . Range: 1 to 3, Unit: Hz
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:SCENter {param}')

	def get(self, subBlock=repcap.SubBlock.Default) -> float:
		"""SCPI: [SENSe]:ESPectrum<sb>:SCENter \n
		Snippet: value: float = driver.sense.espectrum.scenter.get(subBlock = repcap.SubBlock.Default) \n
		This command defines the center frequency of the selected sub block in a Multi-SEM measurement. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:return: frequency: Frequency within the currently defined global span (see [SENSe:]FREQuency:SPAN and [SENSe:]FREQuency:CENTer) . Range: 1 to 3, Unit: Hz"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:SCENter?')
		return Conversions.str_to_float(response)



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaximumCls:
	"""Maximum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maximum", core, parent)

	def get(self, query_range: enums.SelectionRangeB) -> List[float]:
		"""SCPI: [SENSe]:PULSe:EMODel:RMPLevel:MAXimum \n
		Snippet: value: List[float] = driver.applications.k6Pulse.sense.pulse.emodel.riseMidPoint.level.maximum.get(query_range = enums.SelectionRangeB.ALL) \n
		Returns the statistical value for the Rise Mid Point Level over the specified pulses. \n
			:param query_range: CURRent | ALL CURRent Detected pulses in the current capture buffer ALL All detected pulses in the entire measurement.
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(query_range, enums.SelectionRangeB)
		response = self._core.io.query_bin_or_ascii_float_list(f'SENSe:PULSe:EMODel:RMPLevel:MAXimum? {param}')
		return response



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:STATe \n
		Snippet: driver.display.window.state.set(state = False, window = repcap.Window.Default) \n
		This command changes the display state of the selected measurement window. Note that this command is maintained for
		compatibility reasons only. Use the LAYout commands for new remote control programs (See 'Working with windows in the
		display') . \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:STATe {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: DISPlay[:WINDow<n>]:STATe \n
		Snippet: value: bool = driver.display.window.state.get(window = repcap.Window.Default) \n
		This command changes the display state of the selected measurement window. Note that this command is maintained for
		compatibility reasons only. Use the LAYout commands for new remote control programs (See 'Working with windows in the
		display') . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CestimationCls:
	"""Cestimation commands group definition. 7 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cestimation", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def loComp(self):
		"""loComp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_loComp'):
			from .LoComp import LoCompCls
			self._loComp = LoCompCls(self._core, self._cmd_group)
		return self._loComp

	@property
	def cdecimation(self):
		"""cdecimation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cdecimation'):
			from .Cdecimation import CdecimationCls
			self._cdecimation = CdecimationCls(self._core, self._cmd_group)
		return self._cdecimation

	@property
	def mcOffset(self):
		"""mcOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcOffset'):
			from .McOffset import McOffsetCls
			self._mcOffset = McOffsetCls(self._core, self._cmd_group)
		return self._mcOffset

	@property
	def mvelocity(self):
		"""mvelocity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mvelocity'):
			from .Mvelocity import MvelocityCls
			self._mvelocity = MvelocityCls(self._core, self._cmd_group)
		return self._mvelocity

	@property
	def vtolerance(self):
		"""vtolerance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vtolerance'):
			from .Vtolerance import VtoleranceCls
			self._vtolerance = VtoleranceCls(self._core, self._cmd_group)
		return self._vtolerance

	@property
	def transmission(self):
		"""transmission commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_transmission'):
			from .Transmission import TransmissionCls
			self._transmission = TransmissionCls(self._core, self._cmd_group)
		return self._transmission

	def clone(self) -> 'CestimationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CestimationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 6 total commands, 4 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	@property
	def arLevel(self):
		"""arLevel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_arLevel'):
			from .ArLevel import ArLevelCls
			self._arLevel = ArLevelCls(self._core, self._cmd_group)
		return self._arLevel

	@property
	def dutGain(self):
		"""dutGain commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dutGain'):
			from .DutGain import DutGainCls
			self._dutGain = DutGainCls(self._core, self._cmd_group)
		return self._dutGain

	@property
	def dutLimit(self):
		"""dutLimit commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_dutLimit'):
			from .DutLimit import DutLimitCls
			self._dutLimit = DutLimitCls(self._core, self._cmd_group)
		return self._dutLimit

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, level: float) -> None:
		"""SCPI: CONFigure:GENerator:MCGD:LEVel \n
		Snippet: driver.applications.k17Mcgd.configure.generator.mcgd.level.set(level = 1.0) \n
		Sets the specified value on the connected signal generator or queries which value is used. \n
			:param level: Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'CONFigure:GENerator:MCGD:LEVel {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:GENerator:MCGD:LEVel \n
		Snippet: value: float = driver.applications.k17Mcgd.configure.generator.mcgd.level.get() \n
		Sets the specified value on the connected signal generator or queries which value is used. \n
			:return: level: Unit: dBm"""
		response = self._core.io.query_str(f'CONFigure:GENerator:MCGD:LEVel?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'LevelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LevelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LteCls:
	"""Lte commands group definition. 178 total commands, 14 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lte", core, parent)

	@property
	def antMatrix(self):
		"""antMatrix commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_antMatrix'):
			from .AntMatrix import AntMatrixCls
			self._antMatrix = AntMatrixCls(self._core, self._cmd_group)
		return self._antMatrix

	@property
	def caggregation(self):
		"""caggregation commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_caggregation'):
			from .Caggregation import CaggregationCls
			self._caggregation = CaggregationCls(self._core, self._cmd_group)
		return self._caggregation

	@property
	def downlink(self):
		"""downlink commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_downlink'):
			from .Downlink import DownlinkCls
			self._downlink = DownlinkCls(self._core, self._cmd_group)
		return self._downlink

	@property
	def duplexing(self):
		"""duplexing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duplexing'):
			from .Duplexing import DuplexingCls
			self._duplexing = DuplexingCls(self._core, self._cmd_group)
		return self._duplexing

	@property
	def eutra(self):
		"""eutra commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_eutra'):
			from .Eutra import EutraCls
			self._eutra = EutraCls(self._core, self._cmd_group)
		return self._eutra

	@property
	def ldirection(self):
		"""ldirection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ldirection'):
			from .Ldirection import LdirectionCls
			self._ldirection = LdirectionCls(self._core, self._cmd_group)
		return self._ldirection

	@property
	def measurement(self):
		"""measurement commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_measurement'):
			from .Measurement import MeasurementCls
			self._measurement = MeasurementCls(self._core, self._cmd_group)
		return self._measurement

	@property
	def mimo(self):
		"""mimo commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_mimo'):
			from .Mimo import MimoCls
			self._mimo = MimoCls(self._core, self._cmd_group)
		return self._mimo

	@property
	def ndevices(self):
		"""ndevices commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ndevices'):
			from .Ndevices import NdevicesCls
			self._ndevices = NdevicesCls(self._core, self._cmd_group)
		return self._ndevices

	@property
	def noCc(self):
		"""noCc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_noCc'):
			from .NoCc import NoCcCls
			self._noCc = NoCcCls(self._core, self._cmd_group)
		return self._noCc

	@property
	def ooPower(self):
		"""ooPower commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ooPower'):
			from .OoPower import OoPowerCls
			self._ooPower = OoPowerCls(self._core, self._cmd_group)
		return self._ooPower

	@property
	def oran(self):
		"""oran commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_oran'):
			from .Oran import OranCls
			self._oran = OranCls(self._core, self._cmd_group)
		return self._oran

	@property
	def uplink(self):
		"""uplink commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_uplink'):
			from .Uplink import UplinkCls
			self._uplink = UplinkCls(self._core, self._cmd_group)
		return self._uplink

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def clone(self) -> 'LteCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LteCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MeasurementCls:
	"""Measurement commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("measurement", core, parent)

	def set(self, measurement: enums.MeasurementNr5G) -> None:
		"""SCPI: CONFigure[:NR5G]:MEASurement \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.measurement.set(measurement = enums.MeasurementNr5G.ACLR) \n
		This command selects the measurement type. \n
			:param measurement: ACLR Selects the adjacent channel leakage ratio (ACLR) measurement. CACLr Selects the Cumulative ACLR measurement. CMEasurement Selects combined EVM / ACLR / SEM measurement. ESPectrum Selects the spectrum emission mask (SEM) measurement. EVM Selects I/Q measurements. MCAClr Selects Multi-Carrier ACLR measurement. MCESpectrum Selects Multi-Carrier SEM measurement. TAERor Selects the time alignment error measurement. TPOO Selects the transmit on / off power measurement.
		"""
		param = Conversions.enum_scalar_to_str(measurement, enums.MeasurementNr5G)
		self._core.io.write(f'CONFigure:NR5G:MEASurement {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.MeasurementNr5G:
		"""SCPI: CONFigure[:NR5G]:MEASurement \n
		Snippet: value: enums.MeasurementNr5G = driver.applications.k14Xnr5G.configure.nr5G.measurement.get() \n
		This command selects the measurement type. \n
			:return: measurement: ACLR Selects the adjacent channel leakage ratio (ACLR) measurement. CACLr Selects the Cumulative ACLR measurement. CMEasurement Selects combined EVM / ACLR / SEM measurement. ESPectrum Selects the spectrum emission mask (SEM) measurement. EVM Selects I/Q measurements. MCAClr Selects Multi-Carrier ACLR measurement. MCESpectrum Selects Multi-Carrier SEM measurement. TAERor Selects the time alignment error measurement. TPOO Selects the transmit on / off power measurement."""
		response = self._core.io.query_str(f'CONFigure:NR5G:MEASurement?')
		return Conversions.str_to_scalar_enum(response, enums.MeasurementNr5G)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StandardCls:
	"""Standard commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("standard", core, parent)

	def get(self) -> str:
		"""SCPI: CONFigure:GENerator:NPRatio:BB:STANdard \n
		Snippet: value: str = driver.configure.generator.npratio.bb.standard.get() \n
		Queries the standard currently used by the signal generator. \n
			:return: standard: No help available"""
		response = self._core.io.query_str(f'CONFigure:GENerator:NPRatio:BB:STANdard?')
		return trim_str_response(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrameCls:
	"""Frame commands group definition. 131 total commands, 3 Subgroups, 1 group commands
	Repeated Capability: Frame, default value after init: Frame.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frame", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_frame_get', 'repcap_frame_set', repcap.Frame.Nr1)

	def repcap_frame_set(self, frame: repcap.Frame) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Frame.Default
		Default value after init: Frame.Nr1"""
		self._cmd_group.set_repcap_enum_value(frame)

	def repcap_frame_get(self) -> repcap.Frame:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def bwPart(self):
		"""bwPart commands group. 13 Sub-classes, 1 commands."""
		if not hasattr(self, '_bwPart'):
			from .BwPart import BwPartCls
			self._bwPart = BwPartCls(self._core, self._cmd_group)
		return self._bwPart

	@property
	def bwpCount(self):
		"""bwpCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bwpCount'):
			from .BwpCount import BwpCountCls
			self._bwpCount = BwpCountCls(self._core, self._cmd_group)
		return self._bwpCount

	@property
	def paste(self):
		"""paste commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_paste'):
			from .Paste import PasteCls
			self._paste = PasteCls(self._core, self._cmd_group)
		return self._paste

	def copy(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:COPY \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.copy(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default) \n
		This command copies a frame configuration. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
		"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:COPY')

	def copy_with_opc(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, opc_timeout_ms: int = -1) -> None:
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:COPY \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.copy_with_opc(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default) \n
		This command copies a frame configuration. \n
		Same as copy, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:COPY', opc_timeout_ms)

	def clone(self) -> 'FrameCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrameCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def set(self, frequency: float, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:RFUC:FZERo:FREQuency \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.rfuc.fzero.frequency.set(frequency = 1.0, carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects a frequency for RF upconversion.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on phase compensation (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Rfuc.State.set) .
			- Select mode to select custom frequency (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Rfuc.Fzero.Mode.set) . \n
			:param frequency: numeric value Unit: Hz
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:RFUC:FZERo:FREQuency {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:RFUC:FZERo:FREQuency \n
		Snippet: value: float = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.rfuc.fzero.frequency.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects a frequency for RF upconversion.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on phase compensation (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Rfuc.State.set) .
			- Select mode to select custom frequency (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Rfuc.Fzero.Mode.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: frequency: numeric value Unit: Hz"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:RFUC:FZERo:FREQuency?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NofCls:
	"""Nof commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nof", core, parent)

	def set(self, number: float) -> None:
		"""SCPI: TRACe:IQ:EGATe:NOF \n
		Snippet: driver.trace.iq.egate.nof.set(number = 1.0) \n
		This command defines the number of gate periods after the trigger signal for gated measurements with the I/Q analyzer. \n
			:param number: Range: 1 to 1023
		"""
		param = Conversions.decimal_value_to_str(number)
		self._core.io.write(f'TRACe:IQ:EGATe:NOF {param}')

	def get(self) -> float:
		"""SCPI: TRACe:IQ:EGATe:NOF \n
		Snippet: value: float = driver.trace.iq.egate.nof.get() \n
		This command defines the number of gate periods after the trigger signal for gated measurements with the I/Q analyzer. \n
			:return: number: Range: 1 to 1023"""
		response = self._core.io.query_str(f'TRACe:IQ:EGATe:NOF?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LedStateCls:
	"""LedState commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ledState", core, parent)

	def get(self) -> str:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:LEDState \n
		Snippet: value: str = driver.applications.k6Pulse.system.communicate.rdevice.oscilloscope.ledState.get() \n
		Returns the state of the LAN connection to the oscilloscope for the optional 2 GHz / 5 GHz bandwidth extension (R&S
		FSW-B2000/B5000) . For details see 'Alignment'. \n
			:return: led_state: No help available"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:LEDState?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LedStateCls:
	"""LedState commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ledState", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.LedState:
		"""SCPI: CONFigure:REFSignal:GOS:LEDState \n
		Snippet: value: enums.LedState = driver.applications.k18AmplifierEt.configure.refSignal.gos.ledState.get() \n
		This command queries the processing status of an internally generated reference signal. Available when you configure the
		reference signal within the R&S FSW-K18. \n
			:return: state: GREen Generation of the internally generated reference signal was successful. Transmission of the waveform file to the signal generator was also successful. GREY Unknown transmission state. RED Generation and / or transmission of the internally generated reference signal was not successful."""
		response = self._core.io.query_str(f'CONFigure:REFSignal:GOS:LEDState?')
		return Conversions.str_to_scalar_enum(response, enums.LedState)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:SWEep:DTIMe:AUTO \n
		Snippet: driver.sense.sweep.dtime.auto.set(state = False) \n
		This command determines whether the dwell time is defined automatically or manually. For more information see 'Sweep time
		and detector'. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:SWEep:DTIMe:AUTO {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self) -> float:
		"""SCPI: TRACe:IQ:APCon:RESult \n
		Snippet: value: float = driver.trace.iq.apcon.result.get() \n
		Queries the average power consumption for an analog baseband input. This value is only calculated at the end of the I/Q
		data measurement if the method RsFsw.Trace.Iq.Apcon.State.set command is set to ON before the measurement is performed!
		For details see 'Average power consumption'. \n
			:return: average: numeric value Unit: W"""
		response = self._core.io.query_str(f'TRACe:IQ:APCon:RESult?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CdeviceCls:
	"""Cdevice commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cdevice", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Conn_State: float: Defines whether a device is connected or not. 0 No device is connected. 1 A device is connected.
			- Device_Name: float: Device ID of the connected device
			- Serial_Number: float: Serial number of the connected device
			- Port_Name: float: Port name used by the connected device
			- Sample_Rate: float: Current data transfer rate of the connected device in Hz
			- Max_Transfer_Rate: float: Maximum data transfer rate of the connected device in Hz
			- Conn_Prot_State: float: State of the connection protocol which is used to identify the connected device. Not Started Has to be Started Started Passed Failed Done"""
		__meta_args_list = [
			ArgStruct.scalar_float('Conn_State'),
			ArgStruct.scalar_float('Device_Name'),
			ArgStruct.scalar_float('Serial_Number'),
			ArgStruct.scalar_float('Port_Name'),
			ArgStruct.scalar_float('Sample_Rate'),
			ArgStruct.scalar_float('Max_Transfer_Rate'),
			ArgStruct.scalar_float('Conn_Prot_State')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Conn_State: float = None
			self.Device_Name: float = None
			self.Serial_Number: float = None
			self.Port_Name: float = None
			self.Sample_Rate: float = None
			self.Max_Transfer_Rate: float = None
			self.Conn_Prot_State: float = None

	def get(self, outputConnector=repcap.OutputConnector.Default) -> GetStruct:
		"""SCPI: OUTPut<up>:DIQ:CDEVice \n
		Snippet: value: GetStruct = driver.output.diq.cdevice.get(outputConnector = repcap.OutputConnector.Default) \n
		This command queries the current configuration and the status of the digital I/Q data output to the optional 'Digital
		Baseband' interface. For details see 'Interface Status Information'. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		return self._core.io.query_struct(f'OUTPut{outputConnector_cmd_val}:DIQ:CDEVice?', self.__class__.GetStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def set(self, level: enums.LowHigh, outputConnector=repcap.OutputConnector.Default, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: OUTPut<up>:TRIGger<tp>:LEVel \n
		Snippet: driver.applications.k14Xnr5G.output.trigger.level.set(level = enums.LowHigh.HIGH, outputConnector = repcap.OutputConnector.Default, triggerPort = repcap.TriggerPort.Default) \n
		No command help available \n
			:param level: No help available
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.enum_scalar_to_str(level, enums.LowHigh)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:TRIGger{triggerPort_cmd_val}:LEVel {param}')

	# noinspection PyTypeChecker
	def get(self, outputConnector=repcap.OutputConnector.Default, triggerPort=repcap.TriggerPort.Default) -> enums.LowHigh:
		"""SCPI: OUTPut<up>:TRIGger<tp>:LEVel \n
		Snippet: value: enums.LowHigh = driver.applications.k14Xnr5G.output.trigger.level.get(outputConnector = repcap.OutputConnector.Default, triggerPort = repcap.TriggerPort.Default) \n
		No command help available \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: level: No help available"""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:TRIGger{triggerPort_cmd_val}:LEVel?')
		return Conversions.str_to_scalar_enum(response, enums.LowHigh)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PmSettlingCls:
	"""PmSettling commands group definition. 15 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pmSettling", core, parent)

	@property
	def pmSpoint(self):
		"""pmSpoint commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmSpoint'):
			from .PmSpoint import PmSpointCls
			self._pmSpoint = PmSpointCls(self._core, self._cmd_group)
		return self._pmSpoint

	@property
	def pmStime(self):
		"""pmStime commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmStime'):
			from .PmStime import PmStimeCls
			self._pmStime = PmStimeCls(self._core, self._cmd_group)
		return self._pmStime

	@property
	def pmsLength(self):
		"""pmsLength commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmsLength'):
			from .PmsLength import PmsLengthCls
			self._pmsLength = PmsLengthCls(self._core, self._cmd_group)
		return self._pmsLength

	def clone(self) -> 'PmSettlingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PmSettlingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaximumCls:
	"""Maximum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maximum", core, parent)

	def get(self, query_range: enums.SelectionRangeB) -> str:
		"""SCPI: [SENSe]:PULSe:FREQuency:DEViation:MAXimum \n
		Snippet: value: str = driver.applications.k6Pulse.sense.pulse.frequency.deviation.maximum.get(query_range = enums.SelectionRangeB.ALL) \n
		Returns the statistical value for the chirp rate (per μs) over the specified pulses. \n
			:param query_range: CURRent | ALL CURRent Detected pulses in the current capture buffer ALL All detected pulses in the entire measurement.
			:return: result: char_data"""
		param = Conversions.enum_scalar_to_str(query_range, enums.SelectionRangeB)
		response = self._core.io.query_str(f'SENSe:PULSe:FREQuency:DEViation:MAXimum? {param}')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AlternateCls:
	"""Alternate commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Channel, default value after init: Channel.Ch1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("alternate", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_channel_get', 'repcap_channel_set', repcap.Channel.Ch1)

	def repcap_channel_set(self, channel: repcap.Channel) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Channel.Default
		Default value after init: Channel.Ch1"""
		self._cmd_group.set_repcap_enum_value(channel)

	def repcap_channel_get(self) -> repcap.Channel:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, name: str, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:NAME:ALTernate<ch> \n
		Snippet: driver.sense.power.achannel.name.alternate.set(name = '1', channel = repcap.Channel.Default) \n
		This command defines a name for an alternate channel. For MSR ACLR measurements, this command defines the name for the
		lower alternate channel in asymmetric channel definitions. To define the name for the upper alternate channels use the
		[SENSe:]POWer:ACHannel:NAME:UALTernate<ch> command. For details on MSR signals see 'Measurement on multi-standard radio
		(MSR) signals'. \n
			:param name: String containing the name of the channel
			:param channel: optional repeated capability selector. Default value: Ch1 (settable in the interface 'Alternate')
		"""
		param = Conversions.value_to_quoted_str(name)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe:POWer:ACHannel:NAME:ALTernate{channel_cmd_val} {param}')

	def get(self, channel=repcap.Channel.Default) -> str:
		"""SCPI: [SENSe]:POWer:ACHannel:NAME:ALTernate<ch> \n
		Snippet: value: str = driver.sense.power.achannel.name.alternate.get(channel = repcap.Channel.Default) \n
		This command defines a name for an alternate channel. For MSR ACLR measurements, this command defines the name for the
		lower alternate channel in asymmetric channel definitions. To define the name for the upper alternate channels use the
		[SENSe:]POWer:ACHannel:NAME:UALTernate<ch> command. For details on MSR signals see 'Measurement on multi-standard radio
		(MSR) signals'. \n
			:param channel: optional repeated capability selector. Default value: Ch1 (settable in the interface 'Alternate')
			:return: name: String containing the name of the channel"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:NAME:ALTernate{channel_cmd_val}?')
		return trim_str_response(response)

	def clone(self) -> 'AlternateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AlternateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpdateCls:
	"""Update commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("update", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def ledState(self):
		"""ledState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ledState'):
			from .LedState import LedStateCls
			self._ledState = LedStateCls(self._core, self._cmd_group)
		return self._ledState

	def set(self) -> None:
		"""SCPI: CONFigure:DPD:UPDate \n
		Snippet: driver.applications.k18AmplifierEt.configure.dpd.update.set() \n
		This command updates the DPD shaping tables on the R&S SMW when new measurement data is available.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on polynomial DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
		"""
		self._core.io.write(f'CONFigure:DPD:UPDate')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:DPD:UPDate \n
		Snippet: driver.applications.k18AmplifierEt.configure.dpd.update.set_with_opc() \n
		This command updates the DPD shaping tables on the R&S SMW when new measurement data is available.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on polynomial DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:DPD:UPDate', opc_timeout_ms)

	def clone(self) -> 'UpdateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UpdateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimingCls:
	"""Timing commands group definition. 15 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("timing", core, parent)

	@property
	def begin(self):
		"""begin commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_begin'):
			from .Begin import BeginCls
			self._begin = BeginCls(self._core, self._cmd_group)
		return self._begin

	@property
	def dwell(self):
		"""dwell commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_dwell'):
			from .Dwell import DwellCls
			self._dwell = DwellCls(self._core, self._cmd_group)
		return self._dwell

	@property
	def switching(self):
		"""switching commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_switching'):
			from .Switching import SwitchingCls
			self._switching = SwitchingCls(self._core, self._cmd_group)
		return self._switching

	def clone(self) -> 'TimingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TimingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get(self, powerMeter=repcap.PowerMeter.Default) -> int:
		"""SCPI: SYSTem:COMMunicate:RDEVice:PMETer<p>:COUNt \n
		Snippet: value: int = driver.applications.k14Xnr5G.system.communicate.rdevice.pmeter.count.get(powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: result: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:PMETer{powerMeter_cmd_val}:COUNt?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqCls:
	"""Iq commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iq", core, parent)

	def set(self, value: float) -> None:
		"""SCPI: CONFigure:POWer:EXPected:IQ \n
		Snippet: driver.applications.k91Wlan.configure.power.expected.iq.set(value = 1.0) \n
		This command specifies the mean power level of the source signal as supplied to the instrument's digital I/Q input. This
		value is overwritten if 'Auto Level' mode is turned on. \n
			:param value: Unit: V
		"""
		param = Conversions.decimal_value_to_str(value)
		self._core.io.write(f'CONFigure:POWer:EXPected:IQ {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:POWer:EXPected:IQ \n
		Snippet: value: float = driver.applications.k91Wlan.configure.power.expected.iq.get() \n
		This command specifies the mean power level of the source signal as supplied to the instrument's digital I/Q input. This
		value is overwritten if 'Auto Level' mode is turned on. \n
			:return: value: Unit: V"""
		response = self._core.io.query_str(f'CONFigure:POWer:EXPected:IQ?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MagnitudeCls:
	"""Magnitude commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("magnitude", core, parent)

	def get(self, touchStone=repcap.TouchStone.Default, sPortPair=repcap.SPortPair.Ix1) -> float:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SLISt<sli>:DATA:MAGNitude<spi> \n
		Snippet: value: float = driver.sense.correction.fresponse.user.slist.data.magnitude.get(touchStone = repcap.TouchStone.Default, sPortPair = repcap.SPortPair.Ix1) \n
		Queries the trace values for the specified .snp file and ports. \n
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
			:param sPortPair: optional repeated capability selector. Default value: Ix1
			:return: result: No help available"""
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		sPortPair_cmd_val = self._cmd_group.get_repcap_cmd_value(sPortPair, repcap.SPortPair)
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:USER:SLISt{touchStone_cmd_val}:DATA:MAGNitude{sPortPair_cmd_val}?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def set(self, state: bool, scaling: enums.FrequencyScaling = None, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:HOPDetection:TABLe:FREQuency:FREQuency \n
		Snippet: driver.applications.k60Transient.calculate.hopDetection.table.frequency.frequency.set(state = False, scaling = enums.FrequencyScaling.GHZ, window = repcap.Window.Default) \n
		If enabled, the specified frequency parameter is included in the result tables (see 'Frequency parameters') . Note that
		only the enabled columns are returned for the method RsFsw.Applications.K60_Transient.Calculate.HopDetection.Table.
		Results.get_ query. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 The parameter is included. ON | 1 The parameter is not included
			:param scaling: GHZ | MHZ | KHZ | HZ Defines the scaling for the frequency parameters
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('state', state, DataType.Boolean), ArgSingle('scaling', scaling, DataType.Enum, enums.FrequencyScaling, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:HOPDetection:TABLe:FREQuency:FREQuency {param}'.rstrip())

	# noinspection PyTypeChecker
	class FrequencyStruct(StructBase):
		"""Response structure. Fields: \n
			- State: bool: ON | OFF | 0 | 1 OFF | 0 The parameter is included. ON | 1 The parameter is not included
			- Scaling: enums.FrequencyScaling: GHZ | MHZ | KHZ | HZ Defines the scaling for the frequency parameters"""
		__meta_args_list = [
			ArgStruct.scalar_bool('State'),
			ArgStruct.scalar_enum('Scaling', enums.FrequencyScaling)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.State: bool = None
			self.Scaling: enums.FrequencyScaling = None

	def get(self, window=repcap.Window.Default) -> FrequencyStruct:
		"""SCPI: CALCulate<n>:HOPDetection:TABLe:FREQuency:FREQuency \n
		Snippet: value: FrequencyStruct = driver.applications.k60Transient.calculate.hopDetection.table.frequency.frequency.get(window = repcap.Window.Default) \n
		If enabled, the specified frequency parameter is included in the result tables (see 'Frequency parameters') . Note that
		only the enabled columns are returned for the method RsFsw.Applications.K60_Transient.Calculate.HopDetection.Table.
		Results.get_ query. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for FrequencyStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:HOPDetection:TABLe:FREQuency:FREQuency?', self.__class__.FrequencyStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, window_function: enums.WindowFunction) -> None:
		"""SCPI: [SENSe]:LIST:IQWindow:TYPE \n
		Snippet: driver.applications.k40PhaseNoise.sense.listPy.iqWindow.typePy.set(window_function = enums.WindowFunction.BHARris) \n
		No command help available \n
			:param window_function: No help available
		"""
		param = Conversions.enum_scalar_to_str(window_function, enums.WindowFunction)
		self._core.io.write(f'SENSe:LIST:IQWindow:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.WindowFunction:
		"""SCPI: [SENSe]:LIST:IQWindow:TYPE \n
		Snippet: value: enums.WindowFunction = driver.applications.k40PhaseNoise.sense.listPy.iqWindow.typePy.get() \n
		No command help available \n
			:return: window_function: No help available"""
		response = self._core.io.query_str(f'SENSe:LIST:IQWindow:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.WindowFunction)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UsedCls:
	"""Used commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("used", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:TYPE:USED \n
		Snippet: value: float = driver.sense.sweep.typePy.used.get() \n
		This command queries the sweep type if you have turned on automatic selection of the sweep type. \n
			:return: type_py: SWE Normal sweep FFT FFT mode"""
		response = self._core.io.query_str(f'SENSe:SWEep:TYPE:USED?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdCls:
	"""Id commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("id", core, parent)

	def get(self, query_range: enums.SelectionRangeB) -> int:
		"""SCPI: [SENSe]:PULSe:ID \n
		Snippet: value: int = driver.applications.k6Pulse.sense.pulse.id.get(query_range = enums.SelectionRangeB.ALL) \n
		Queries the ids of the detected pulses, i.e the unique index within the entire measurement (as opposed to
		[SENSe:]PULSe:NUMBer?) . \n
			:param query_range: CURRent | ALL CURRent Detected pulses in the current capture buffer ALL All detected pulses in the entire measurement.
			:return: pulse_id: No help available"""
		param = Conversions.enum_scalar_to_str(query_range, enums.SelectionRangeB)
		response = self._core.io.query_str(f'SENSe:PULSe:ID? {param}')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default, subBlock=repcap.SubBlock.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer<sb>:STANdard:CATalog \n
		Snippet: value: float = driver.calculate.marker.function.power.standard.catalog.get(window = repcap.Window.Default, marker = repcap.Marker.Default, subBlock = repcap.SubBlock.Default) \n
		This command queries all files containing ACLR standards. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
			:return: standards: List of standard files."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer{subBlock_cmd_val}:STANdard:CATalog?')
		return Conversions.str_to_float(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LedStateCls:
	"""LedState commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ledState", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.LedState:
		"""SCPI: CONFigure:GENerator:DUT:INPut:MAXimum:POWer:LEDState \n
		Snippet: value: enums.LedState = driver.applications.k18AmplifierEt.configure.generator.dut.inputPy.maximum.power.ledState.get() \n
		This command queries the maximum output level configuration state on the generator. \n
			:return: state: GREen Configuration was successful. GREY Unknown configuration state. RED Configuration to the reference was not successful."""
		response = self._core.io.query_str(f'CONFigure:GENerator:DUT:INPut:MAXimum:POWer:LEDState?')
		return Conversions.str_to_scalar_enum(response, enums.LedState)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrameCls:
	"""Frame commands group definition. 8 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frame", core, parent)

	@property
	def count(self):
		"""count commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def optimization(self):
		"""optimization commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_optimization'):
			from .Optimization import OptimizationCls
			self._optimization = OptimizationCls(self._core, self._cmd_group)
		return self._optimization

	@property
	def saLevel(self):
		"""saLevel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_saLevel'):
			from .SaLevel import SaLevelCls
			self._saLevel = SaLevelCls(self._core, self._cmd_group)
		return self._saLevel

	@property
	def scount(self):
		"""scount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scount'):
			from .Scount import ScountCls
			self._scount = ScountCls(self._core, self._cmd_group)
		return self._scount

	@property
	def slot(self):
		"""slot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_slot'):
			from .Slot import SlotCls
			self._slot = SlotCls(self._core, self._cmd_group)
		return self._slot

	@property
	def srSlot(self):
		"""srSlot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srSlot'):
			from .SrSlot import SrSlotCls
			self._srSlot = SrSlotCls(self._core, self._cmd_group)
		return self._srSlot

	def clone(self) -> 'FrameCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrameCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrachCls:
	"""Prach commands group definition. 9 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prach", core, parent)

	@property
	def apm(self):
		"""apm commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apm'):
			from .Apm import ApmCls
			self._apm = ApmCls(self._core, self._cmd_group)
		return self._apm

	@property
	def conf(self):
		"""conf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conf'):
			from .Conf import ConfCls
			self._conf = ConfCls(self._core, self._cmd_group)
		return self._conf

	@property
	def foffset(self):
		"""foffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_foffset'):
			from .Foffset import FoffsetCls
			self._foffset = FoffsetCls(self._core, self._cmd_group)
		return self._foffset

	@property
	def frIndex(self):
		"""frIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frIndex'):
			from .FrIndex import FrIndexCls
			self._frIndex = FrIndexCls(self._core, self._cmd_group)
		return self._frIndex

	@property
	def hfIndicator(self):
		"""hfIndicator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hfIndicator'):
			from .HfIndicator import HfIndicatorCls
			self._hfIndicator = HfIndicatorCls(self._core, self._cmd_group)
		return self._hfIndicator

	@property
	def ncsc(self):
		"""ncsc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ncsc'):
			from .Ncsc import NcscCls
			self._ncsc = NcscCls(self._core, self._cmd_group)
		return self._ncsc

	@property
	def rseq(self):
		"""rseq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rseq'):
			from .Rseq import RseqCls
			self._rseq = RseqCls(self._core, self._cmd_group)
		return self._rseq

	@property
	def rset(self):
		"""rset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rset'):
			from .Rset import RsetCls
			self._rset = RsetCls(self._core, self._cmd_group)
		return self._rset

	@property
	def sindex(self):
		"""sindex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sindex'):
			from .Sindex import SindexCls
			self._sindex = SindexCls(self._core, self._cmd_group)
		return self._sindex

	def clone(self) -> 'PrachCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PrachCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllocCls:
	"""Alloc commands group definition. 12 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("alloc", core, parent)

	@property
	def cluster(self):
		"""cluster commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cluster'):
			from .Cluster import ClusterCls
			self._cluster = ClusterCls(self._core, self._cmd_group)
		return self._cluster

	@property
	def cont(self):
		"""cont commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cont'):
			from .Cont import ContCls
			self._cont = ContCls(self._core, self._cmd_group)
		return self._cont

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def precoding(self):
		"""precoding commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_precoding'):
			from .Precoding import PrecodingCls
			self._precoding = PrecodingCls(self._core, self._cmd_group)
		return self._precoding

	@property
	def puach(self):
		"""puach commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_puach'):
			from .Puach import PuachCls
			self._puach = PuachCls(self._core, self._cmd_group)
		return self._puach

	@property
	def pucch(self):
		"""pucch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pucch'):
			from .Pucch import PucchCls
			self._pucch = PucchCls(self._core, self._cmd_group)
		return self._pucch

	@property
	def pusch(self):
		"""pusch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pusch'):
			from .Pusch import PuschCls
			self._pusch = PuschCls(self._core, self._cmd_group)
		return self._pusch

	@property
	def rato(self):
		"""rato commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rato'):
			from .Rato import RatoCls
			self._rato = RatoCls(self._core, self._cmd_group)
		return self._rato

	def clone(self) -> 'AllocCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AllocCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PmStimeCls:
	"""PmStime commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pmStime", core, parent)

	def set(self, state: bool, scaling: enums.TimeScaling = None, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:HOPDetection:TABLe:PMSettling:PMSTime \n
		Snippet: driver.applications.k60Transient.calculate.hopDetection.table.pmSettling.pmStime.set(state = False, scaling = enums.TimeScaling.MS, window = repcap.Window.Default) \n
		If enabled, the PM settling time parameter is included in the result tables (see 'PM settling time') . Note that only the
		enabled columns are returned for the method RsFsw.Applications.K60_Transient.Calculate.HopDetection.Table.Results.
		get_ query. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param scaling: S | MS | US | NS Defines the scaling for the FM settling parameters
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('state', state, DataType.Boolean), ArgSingle('scaling', scaling, DataType.Enum, enums.TimeScaling, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:HOPDetection:TABLe:PMSettling:PMSTime {param}'.rstrip())

	# noinspection PyTypeChecker
	class PmStimeStruct(StructBase):
		"""Response structure. Fields: \n
			- State: bool: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			- Scaling: enums.TimeScaling: S | MS | US | NS Defines the scaling for the FM settling parameters"""
		__meta_args_list = [
			ArgStruct.scalar_bool('State'),
			ArgStruct.scalar_enum('Scaling', enums.TimeScaling)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.State: bool = None
			self.Scaling: enums.TimeScaling = None

	def get(self, window=repcap.Window.Default) -> PmStimeStruct:
		"""SCPI: CALCulate<n>:HOPDetection:TABLe:PMSettling:PMSTime \n
		Snippet: value: PmStimeStruct = driver.applications.k60Transient.calculate.hopDetection.table.pmSettling.pmStime.get(window = repcap.Window.Default) \n
		If enabled, the PM settling time parameter is included in the result tables (see 'PM settling time') . Note that only the
		enabled columns are returned for the method RsFsw.Applications.K60_Transient.Calculate.HopDetection.Table.Results.
		get_ query. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for PmStimeStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:HOPDetection:TABLe:PMSettling:PMSTime?', self.__class__.PmStimeStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, data_type: enums.IqType, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:IQ:TYPE \n
		Snippet: driver.inputPy.iq.typePy.set(data_type = enums.IqType.Ipart=I, inputIx = repcap.InputIx.Default) \n
		This command defines the format of the input signal. \n
			:param data_type: IQ | I | Q IQ The input signal is filtered and resampled to the sample rate of the application. Two input channels are required for each input signal, one for the in-phase component, and one for the quadrature component. I The in-phase component of the input signal is filtered and resampled to the sample rate of the application. If the center frequency is not 0, the in-phase component of the input signal is down-converted first (Low IF I) . Q The quadrature component of the input signal is filtered and resampled to the sample rate of the application. If the center frequency is not 0, the quadrature component of the input signal is down-converted first (Low IF Q) .
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(data_type, enums.IqType)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:IQ:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.IqType:
		"""SCPI: INPut<ip>:IQ:TYPE \n
		Snippet: value: enums.IqType = driver.inputPy.iq.typePy.get(inputIx = repcap.InputIx.Default) \n
		This command defines the format of the input signal. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: data_type: IQ | I | Q IQ The input signal is filtered and resampled to the sample rate of the application. Two input channels are required for each input signal, one for the in-phase component, and one for the quadrature component. I The in-phase component of the input signal is filtered and resampled to the sample rate of the application. If the center frequency is not 0, the in-phase component of the input signal is down-converted first (Low IF I) . Q The quadrature component of the input signal is filtered and resampled to the sample rate of the application. If the center frequency is not 0, the quadrature component of the input signal is down-converted first (Low IF Q) ."""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IQ:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.IqType)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UaChannelCls:
	"""UaChannel commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uaChannel", core, parent)

	def set(self, spacing: float) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:UACHannel \n
		Snippet: driver.sense.power.achannel.spacing.uaChannel.set(spacing = 1.0) \n
		This command defines the distance from the transmission channel to the upper adjacent channel. For MSR signals, this
		command defines the distance from the CF of the last Tx channel in the last sub block to the upper adjacent channel in
		asymmetrical configurations. To configure the spacing for the lower adjacent channel use the
		[SENSe:]POWer:ACHannel:SPACing[:ACHannel] command. \n
			:param spacing: Range: 100 Hz to 2000 MHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(spacing)
		self._core.io.write(f'SENSe:POWer:ACHannel:SPACing:UACHannel {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:UACHannel \n
		Snippet: value: float = driver.sense.power.achannel.spacing.uaChannel.get() \n
		This command defines the distance from the transmission channel to the upper adjacent channel. For MSR signals, this
		command defines the distance from the CF of the last Tx channel in the last sub block to the upper adjacent channel in
		asymmetrical configurations. To configure the spacing for the lower adjacent channel use the
		[SENSe:]POWer:ACHannel:SPACing[:ACHannel] command. \n
			:return: spacing: Range: 100 Hz to 2000 MHz, Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SPACing:UACHannel?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScopeCls:
	"""Scope commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scope", core, parent)

	def set(self, scope: enums.ScaleScope, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe]:SCOPe \n
		Snippet: driver.applications.k40PhaseNoise.display.window.trace.x.scale.scope.set(scope = enums.ScaleScope.HDECades, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command selects the way the application scales the horizontal axis. \n
			:param scope: MRANge | HDECades | MANual MRANge Shows the complete measurement range. HDECade Shows a particular half decade only. You can select a particular half decade with . MANual Shows a custom part of the measurement range. You can select the start and stop offsets with .
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(scope, enums.ScaleScope)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe:SCOPe {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> enums.ScaleScope:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe]:SCOPe \n
		Snippet: value: enums.ScaleScope = driver.applications.k40PhaseNoise.display.window.trace.x.scale.scope.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command selects the way the application scales the horizontal axis. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: scope: MRANge | HDECades | MANual MRANge Shows the complete measurement range. HDECade Shows a particular half decade only. You can select a particular half decade with . MANual Shows a custom part of the measurement range. You can select the start and stop offsets with ."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe:SCOPe?')
		return Conversions.str_to_scalar_enum(response, enums.ScaleScope)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self) -> None:
		"""SCPI: INITiate[:IMMediate] \n
		Snippet: driver.applications.k17Mcgd.initiate.immediate.set() \n
		This command starts a (single) new measurement. With sweep count or average count > 0, this means a restart of the
		corresponding number of measurements. With trace mode MAXHold, MINHold and AVERage, the previous results are reset on
		restarting the measurement. You can synchronize to the end of the measurement with *OPC, *OPC? or *WAI. For details on
		synchronization see Remote control via SCPI. \n
		"""
		self._core.io.write(f'INITiate:IMMediate')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INITiate[:IMMediate] \n
		Snippet: driver.applications.k17Mcgd.initiate.immediate.set_with_opc() \n
		This command starts a (single) new measurement. With sweep count or average count > 0, this means a restart of the
		corresponding number of measurements. With trace mode MAXHold, MINHold and AVERage, the previous results are reset on
		restarting the measurement. You can synchronize to the end of the measurement with *OPC, *OPC? or *WAI. For details on
		synchronization see Remote control via SCPI. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INITiate:IMMediate', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModulationCls:
	"""Modulation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("modulation", core, parent)

	def set(self, tx_filter: str, rx_filter: str) -> None:
		"""SCPI: [SENSe]:DEMod:FILTer:MODulation \n
		Snippet: driver.applications.k91Wlan.sense.demod.filterPy.modulation.set(tx_filter = '1', rx_filter = '1') \n
		This command selects the transmit (TX) and receive (RX) filters. The names of the filters correspond to the file names; a
		query of all available filters is possible by means of the [SENSe:]DEMod:FILTer:CATalog? command. This command is only
		available for IEEE 802.11b measurements. \n
			:param tx_filter: File name of the transmit filter
			:param rx_filter: File name of the receive filter
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('tx_filter', tx_filter, DataType.String), ArgSingle('rx_filter', rx_filter, DataType.String))
		self._core.io.write(f'SENSe:DEMod:FILTer:MODulation {param}'.rstrip())

	# noinspection PyTypeChecker
	class ModulationStruct(StructBase):
		"""Response structure. Fields: \n
			- Tx_Filter: str: File name of the transmit filter
			- Rx_Filter: str: File name of the receive filter"""
		__meta_args_list = [
			ArgStruct.scalar_str('Tx_Filter'),
			ArgStruct.scalar_str('Rx_Filter')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Tx_Filter: str = None
			self.Rx_Filter: str = None

	def get(self) -> ModulationStruct:
		"""SCPI: [SENSe]:DEMod:FILTer:MODulation \n
		Snippet: value: ModulationStruct = driver.applications.k91Wlan.sense.demod.filterPy.modulation.get() \n
		This command selects the transmit (TX) and receive (RX) filters. The names of the filters correspond to the file names; a
		query of all available filters is possible by means of the [SENSe:]DEMod:FILTer:CATalog? command. This command is only
		available for IEEE 802.11b measurements. \n
			:return: structure: for return value, see the help for ModulationStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:DEMod:FILTer:MODulation?', self.__class__.ModulationStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CouplingCls:
	"""Coupling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coupling", core, parent)

	def set(self, coup_type: enums.CouplingTypeB) -> None:
		"""SCPI: TRIGger[:SEQuence]:OSCilloscope:COUPling \n
		Snippet: driver.applications.k60Transient.trigger.sequence.oscilloscope.coupling.set(coup_type = enums.CouplingTypeB.AC) \n
		Configures the coupling of the external trigger to the oscilloscope. \n
			:param coup_type: Coupling type DC Direct connection with 50 Ω termination, passes both DC and AC components of the trigger signal. CDLimit Direct connection with 1 MΩ termination, passes both DC and AC components of the trigger signal. AC Connection through capacitor, removes unwanted DC and very low-frequency components.
		"""
		param = Conversions.enum_scalar_to_str(coup_type, enums.CouplingTypeB)
		self._core.io.write(f'TRIGger:SEQuence:OSCilloscope:COUPling {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.CouplingTypeB:
		"""SCPI: TRIGger[:SEQuence]:OSCilloscope:COUPling \n
		Snippet: value: enums.CouplingTypeB = driver.applications.k60Transient.trigger.sequence.oscilloscope.coupling.get() \n
		Configures the coupling of the external trigger to the oscilloscope. \n
			:return: coup_type: Coupling type DC Direct connection with 50 Ω termination, passes both DC and AC components of the trigger signal. CDLimit Direct connection with 1 MΩ termination, passes both DC and AC components of the trigger signal. AC Connection through capacitor, removes unwanted DC and very low-frequency components."""
		response = self._core.io.query_str(f'TRIGger:SEQuence:OSCilloscope:COUPling?')
		return Conversions.str_to_scalar_enum(response, enums.CouplingTypeB)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AddressCls:
	"""Address commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Antenna, default value after init: Antenna.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("address", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_antenna_get', 'repcap_antenna_set', repcap.Antenna.Nr1)

	def repcap_antenna_set(self, antenna: repcap.Antenna) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Antenna.Default
		Default value after init: Antenna.Nr1"""
		self._cmd_group.set_repcap_enum_value(antenna)

	def repcap_antenna_get(self) -> repcap.Antenna:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, address: str, antenna=repcap.Antenna.Default) -> None:
		"""SCPI: CONFigure:WLAN:ANTMatrix:ADDRess<ant> \n
		Snippet: driver.applications.k91Wlan.configure.wlan.antMatrix.address.set(address = '1', antenna = repcap.Antenna.Default) \n
		This remote control command specifies the TCP/IP address for each receiver path in IPV4 format. Note, it is not possible
		to set the IP address of ANTMatrix1 (primary) \n
			:param address: TCP/IP address in IPV4 format
			:param antenna: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Address')
		"""
		param = Conversions.value_to_quoted_str(address)
		antenna_cmd_val = self._cmd_group.get_repcap_cmd_value(antenna, repcap.Antenna)
		self._core.io.write(f'CONFigure:WLAN:ANTMatrix:ADDRess{antenna_cmd_val} {param}')

	def get(self, antenna=repcap.Antenna.Default) -> str:
		"""SCPI: CONFigure:WLAN:ANTMatrix:ADDRess<ant> \n
		Snippet: value: str = driver.applications.k91Wlan.configure.wlan.antMatrix.address.get(antenna = repcap.Antenna.Default) \n
		This remote control command specifies the TCP/IP address for each receiver path in IPV4 format. Note, it is not possible
		to set the IP address of ANTMatrix1 (primary) \n
			:param antenna: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Address')
			:return: address: TCP/IP address in IPV4 format"""
		antenna_cmd_val = self._cmd_group.get_repcap_cmd_value(antenna, repcap.Antenna)
		response = self._core.io.query_str(f'CONFigure:WLAN:ANTMatrix:ADDRess{antenna_cmd_val}?')
		return trim_str_response(response)

	def clone(self) -> 'AddressCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AddressCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SenseCls:
	"""Sense commands group definition. 68 total commands, 16 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def ademod(self):
		"""ademod commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_ademod'):
			from .Ademod import AdemodCls
			self._ademod = AdemodCls(self._core, self._cmd_group)
		return self._ademod

	@property
	def iq(self):
		"""iq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def probe(self):
		"""probe commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_probe'):
			from .Probe import ProbeCls
			self._probe = ProbeCls(self._core, self._cmd_group)
		return self._probe

	@property
	def rawPhase(self):
		"""rawPhase commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rawPhase'):
			from .RawPhase import RawPhaseCls
			self._rawPhase = RawPhaseCls(self._core, self._cmd_group)
		return self._rawPhase

	@property
	def adjust(self):
		"""adjust commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def bandwidth(self):
		"""bandwidth commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def frequency(self):
		"""frequency commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def carrier(self):
		"""carrier commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_carrier'):
			from .Carrier import CarrierCls
			self._carrier = CarrierCls(self._core, self._cmd_group)
		return self._carrier

	@property
	def clock(self):
		"""clock commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def sweep(self):
		"""sweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def average(self):
		"""average commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_average'):
			from .Average import AverageCls
			self._average = AverageCls(self._core, self._cmd_group)
		return self._average

	@property
	def subspan(self):
		"""subspan commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_subspan'):
			from .Subspan import SubspanCls
			self._subspan = SubspanCls(self._core, self._cmd_group)
		return self._subspan

	@property
	def mtime(self):
		"""mtime commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_mtime'):
			from .Mtime import MtimeCls
			self._mtime = MtimeCls(self._core, self._cmd_group)
		return self._mtime

	@property
	def rlength(self):
		"""rlength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rlength'):
			from .Rlength import RlengthCls
			self._rlength = RlengthCls(self._core, self._cmd_group)
		return self._rlength

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def cestimation(self):
		"""cestimation commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_cestimation'):
			from .Cestimation import CestimationCls
			self._cestimation = CestimationCls(self._core, self._cmd_group)
		return self._cestimation

	def clone(self) -> 'SenseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SenseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
